@@ -1,4 +1,5 @@
 from django.db import models
+from django.core import signing
 from django.contrib.auth.models import AbstractUser
 from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import slugify
@@ -9,18 +10,20 @@ class BaseUser(AbstractUser):
     name = models.CharField(_('name'), max_length=255, blank=True)
     first_login = models.BooleanField(_('first login'), default=True)
     image = models.ImageField(_('image'), blank=True, null=True, upload_to="images/avatars/%Y/%m/%d", max_length=255)
+    confirmed = models.DateTimeField(null=True, blank=True)
 
     class Meta:
         abstract = True
 
     def save(self, *args, **kwargs):
 
-        # Create slug from username. Altough field is not unique at database
-        # level, it will be as long as username stays unique as well.
+        # Create slug from username. Although ``BaseUser.slug`` field is not
+        # unique at database level, it will be unique as long as
+        # ``AbstractUser.username`` stays unique as well.
         if not self.id:
             self.slug = slugify(self.username)
 
-        # Assign username as name if empty
+        # Assign ``AbstractUser.username`` as ``BaseUser.name`` if empty
         if not self.name.strip():
             if not self.first_name:
                 self.first_name = self.username
@@ -31,3 +34,6 @@ class BaseUser(AbstractUser):
 
     def get_display_name(self):
         return self.name or self.username
+
+    def get_confirmation_token(self):
+        return signing.dumps(self.pk)
