@@ -2,10 +2,14 @@
 
 from django.views.generic import View, FormView
 from django.contrib.auth import login, authenticate, logout
-from django.shortcuts import redirect
+from django.shortcuts import redirect, get_object_or_404
 from django.utils.translation import ugettext as _
+from django.utils.timezone import now
 from django.conf import settings
+from django.http import Http404
+from django.core import signing
 from django.core.urlresolvers import reverse_lazy
+from django.contrib.auth import get_user_model
 
 from base_accounts.forms import SignupForm, LoginForm, UpdateEmailForm, UpdatePasswordForm
 from base_accounts.utils import create_email_user, UserAlreadyExists
@@ -119,7 +123,7 @@ class UpdateEmailFormView(SuccessMessageMixin, ErrorMessageRedirectMixin, FormVi
     form_class = UpdateEmailForm
     template_name = 'base_accounts/update_email.html'
     success_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_EMAIL_REDIRECT_URL', reverse_lazy('settings_update_email'))
-    error_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_EMAIL_ERROR_REDIRECT_URL', '')
+    error_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_EMAIL_ERROR_REDIRECT_URL', reverse_lazy('settings_update_email'))
     success_message = _('You have updated your email successfully')
 
     def get_form_kwargs(self):
@@ -129,8 +133,11 @@ class UpdateEmailFormView(SuccessMessageMixin, ErrorMessageRedirectMixin, FormVi
         return kwargs
 
     def form_valid(self, form):
-        self.request.user.email = form.cleaned_data.get('email')
-        self.request.user.save(update_fields=['email'])
+        new_email = form.cleaned_data.get('email')
+        if self.request.user.email != new_email:
+            self.request.user.email = new_email
+            self.request.user.confirmed = None
+            self.request.user.save()
         return super(UpdateEmailFormView, self).form_valid(form)
 
 
@@ -139,7 +146,7 @@ class UpdatePasswordFormView(SuccessMessageMixin, ErrorMessageRedirectMixin, For
     form_class = UpdatePasswordForm
     template_name = 'base_accounts/update_password.html'
     success_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_PASSWORD_REDIRECT_URL', reverse_lazy('settings_update_password'))
-    error_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_PASSWORD_ERROR_REDIRECT_URL', '')
+    error_url = getattr(settings, 'BASE_ACCOUNTS_UPDATE_PASSWORD_ERROR_REDIRECT_URL', reverse_lazy('settings_update_password'))
     success_message = _('You have updated your password successfully')
 
     def get_form_kwargs(self):
@@ -179,3 +186,32 @@ class LogoutView(View):
             user.save(update_fields=['first_login'])
         logout(request)
         return redirect(self.success_url)
+
+
+def confirm_email_address(request, token):
+    """Confirms user's email address"""
+    try:
+        pk = signing.loads(token, max_age=3600 * 48, salt='resend_email_confirmation')
+    except signing.BadSignature:
+        raise Http404
+    user = get_object_or_404(get_user_model(), pk=pk)
+
+    if user.confirmed:
+        raise Http404
+
+    user.confirmed = now()
+    user.save()
+
+    if request.user != user:
+        logout(request)
+
+    if not request.user.is_authenticated():
+        user.backend = 'django.contrib.auth.backends.ModelBackend'
+        login(request, user)
+
+    if user.is_active:
+        messages.success(request, _('You have confirmed your email address'))
+        return redirect('settings_update_email')
+    else:
+        messages.success(request, _('Please confirm your email address'))
+        return redirect('password_reset_recover')
